# Generated by Django 3.2.6 on 2022-07-15 09:56

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('wooey', '0043_update_model_protection'),
    ]

    operations = [
        migrations.AlterField(
            model_name='scriptparameter',
            name='choices',
            field=models.TextField(blank=True, null=True),
        ),
    ]
